<?php

class JournalController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters()
    {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules()
    {
        return array(
            array('allow',
                'actions' => array('index', 'view', 'create', 'update', 'admin', 'delete', 'addMax', 'editMax', 'editArticlesMax'),
                'users' => array('@'),
            ),
            array('allow',
                'actions' => array('json'),
                'users' => array('*'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id)
    {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate()
    {
        $model = new Journal;

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Journal']))
        {
            $model->attributes = $_POST['Journal'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id)
    {
        $model = $this->loadModel($id);

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Journal']))
        {
            $model->attributes = $_POST['Journal'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id)
    {
        $this->loadModel($id)->delete();

        // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
        if (!isset($_GET['ajax']))
            $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
    }

    /**
     * Lists all models.
     */
    public function actionIndex()
    {
        $dataProvider = new CActiveDataProvider('Journal');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin()
    {
        $model = new Journal('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Journal']))
            $model->attributes = $_GET['Journal'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    public function actionJson()
    {
        $dataArray = Journal::model()->findAll();

        $this->layout = false;
        header('Content-type: application/json');
        echo CJavaScript::jsonEncode($dataArray);
        Yii::app()->end();
    }

    public function actionAddMax()
    {
        $model = new JournalMaxForm;

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['JournalMaxForm']))
        {
     
            $model->attributes = $_POST['JournalMaxForm'];
            
            
            
            if ($this->saveJournalForm($model))
            {
                $this->redirect(array('editArticlesMax'));
            } else
            {
                $this->redirect(array('editMax'));
            }
            return;
        }

        $this->render('addMax', array(
            'model' => $model,
        ));
    }

    public function actionEditMax()
    {
        
        $model = new JournalMaxForm;
        
        if (isset($_POST['JournalMaxForm']))
        {
            $model->attributes = $_POST['JournalMaxForm'];

            if ($this->saveJournalForm($model))
            {
                $this->redirect(array('editArticlesMax'));
            } else
            {
                $this->redirect(array('editMax'));
            }
            return;
        }
        
        
        $currentJournal = Journal::getCurrentUserJournal();
        if ($currentJournal)
        {
            $titleTranslationModel = Translation::model()->find('name=:name', array(':name' => Yii::app()->user->name . '_journal_title_translation'));
            if ($titleTranslationModel)
            {
                $model->titleRu = $titleTranslationModel->textRu;
                $model->titleEn = $titleTranslationModel->textEn;
                $model->titleZh = $titleTranslationModel->textZh;
            }

            $descriptionTranslationModel = Translation::model()->find('name=:name', array(':name' => Yii::app()->user->name . '_journal_description_translation'));
            if ($descriptionTranslationModel)
            {
                $model->descriptionRu = $descriptionTranslationModel->textRu;
                $model->descriptionEn = $descriptionTranslationModel->textEn;
                $model->descriptionZh = $descriptionTranslationModel->textZh;
            }
        }

        $this->render('editMax', array(
            'model' => $model,
        ));
    }

    public function actionEditArticlesMax()
    {

        $articleNameArr = ArticleJournalRelation::model()->findAll('journalName=:journalName', array(':journalName' => Yii::app()->user->name . '_journal'));

        
        $articleArr = array();
        foreach ($articleNameArr as $articleRelation)
        {
            $article = Article::model()->find('name=:name', array(':name' => $articleRelation->articleName));
            $article->title = Translation::model()->find('name=:name', array(':name' => $article->title))->textRu;
            
            $articleArr[] = $article;
        }
        
        $this->render('editArticlesMax', array(
            'articleArr' => $articleArr,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer $id the ID of the model to be loaded
     * @return Journal the loaded model
     * @throws CHttpException
     */
    public function loadModel($id)
    {
        $model = Journal::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param Journal $model the model to be validated
     */
    protected function performAjaxValidation($model)
    {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'journal-form')
        {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    protected function saveJournalForm($model)
    {

        if (empty($model->titleEn))
        {
            $model->titleEn = 'NEED_TRANSLATION';
        }
        if (empty($model->titleZh))
        {
            $model->titleZh = 'NEED_TRANSLATION';
        }
        if (empty($model->descriptionEn))
        {
            $model->descriptionEn = 'NEED_TRANSLATION';
        }
        if (empty($model->descriptionZh))
        {
            $model->descriptionZh = 'NEED_TRANSLATION';
        }

        $journalModel = Journal::getCurrentUserJournal();
        
        if (!Journal::getCurrentUserJournal())
        {

            $journalModel = new Journal;
        }

        $journalModel->name = Yii::app()->user->name . '_journal';
        $journalModel->title = Yii::app()->user->name . '_journal_title_translation';
        $journalModel->description = Yii::app()->user->name . '_journal_description_translation';


        $titleTranslationModel = Translation::model()->find('name=:name', array(':name' => Yii::app()->user->name . '_journal_title_translation'));
        if ($titleTranslationModel === null)
        {
            $titleTranslationModel = new Translation;
        }

        $titleTranslationModel->name = Yii::app()->user->name . '_journal_title_translation';
        $titleTranslationModel->textRu = $model->titleRu;
        $titleTranslationModel->textEn = $model->titleEn;
        $titleTranslationModel->textZh = $model->titleZh;
        $titleTranslationModel->save();


        $descriptionTranslationModel = Translation::model()->find('name=:name', array(':name' => Yii::app()->user->name . '_journal_description_translation'));
        if ($descriptionTranslationModel === null)
        {
            $descriptionTranslationModel = new Translation;
        }


        $descriptionTranslationModel->name = Yii::app()->user->name . '_journal_description_translation';
        $descriptionTranslationModel->textRu = $model->descriptionRu;
        $descriptionTranslationModel->textEn = $model->descriptionEn;
        $descriptionTranslationModel->textZh = $model->descriptionZh;
        $descriptionTranslationModel->save();


        return $journalModel->save();
    }

}
